@@ -10,7 +10,7 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 //
 //
-// $Id: match.c 175 2009-01-25 13:33:01Z jessekornblum $ 
+// $Id: match.c 188 2009-04-20 10:28:52Z jessekornblum $ 
 
 #include "main.h"
 #include "hashTable.h"
@@ -239,7 +239,9 @@ int is_known_hash(char *h, char *known_fn)
 {
   int status;
 
-  if (NULL == h || NULL == known_fn)
+  // We don't check if the known_fn parameter is NULL because
+  // that's a legitimate call in hash.c under mode_not_matched
+  if (NULL == h)
     internal_error("%s: Null values passed into is_known_hash",
 		   __progname);
 
